@@ -193,6 +193,8 @@ class TigerCorpusReader(Corpus):
             except IOError:
                 self.tiger_sents = []
                 print u"Error: TIGER corpus file not found. Please follow README to download and place it properly."
+                print u"       (A file named " + C.CORPUS_FILES.get(u"de", u"")
+                print u"        needs to be placed here: " + TigerCorpusReader.STORAGE_ROOT + u")"
 
     def _fast_iter(self, context, func):
         buf = list()
